@@ -1,3 +1,3 @@
 # APIs to put directly under the package namespace
 from .domecab import do_mecab, do_mecab_vec, do_mecab_iter
-from .api     import tokenize
+from .api import tokenize, print_token, mecab_batch, mecab_batch_iter, MecabTokenizer
